tbmp
======

A Python module for displaying bitmaps in the terminal as strings of block characters.

Installation
------------

To install with pip, run:

    pip install tbmp

Quickstart Guide
----------------

TODO - fill this in later

Contribute
----------

If you'd like to contribute to tbmp, check out https://github.com/asweigart/tbmp
